==> select-ss-user-result-0.0.41.tgz: package/esm/index.js <==
import React, { useCallback, useState, useEffect } from 'react';
import { Button } from 'antd';
// @ts-ignore
import SelectUser from 'select-ss-user';
import SelectUserResult from './select-user-result';
import net from './services/index';
export default ({ onChange, selectUserProps, isNotDom = false, ...others }) => {
    const [groupList, setGroupList] = useState([]);
    const [data, setData] = useState({});
    const [selectSignature, setSelectSignature] = useState(selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.selectSignature);
    const { btnText = '选择', btnDisiabled = false, resultTitle = '已选对象', btnDetele = false, btnUpdate = true, } = others;
    useEffect(() => {
        if (selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.selectSignature) {
            net
                .request(`${selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.userOrigin}/select/component/result?selectSignature=${selectSignature}`, {
                method: 'GET',
            })
                .then(({ data }) => {
                setData(data);
                setSelectSignature(selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.selectSignature);
                if ((selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.getCheckedNodes) &&
                    typeof (selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.getCheckedNodes) === 'function') {
                    selectUserProps.getCheckedNodes(data);
                }
            });
        }
    }, [selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.selectSignature]);
    useEffect(() => {
        const { userInfoList = [], deptInfoList = [], orgInfoList = [], groupInfoList = [], tagInfoList = [], equipmentInfoList = [], orgRelInfoList = [], } = data || {};
        const { selectPaneProps } = selectUserProps;
        const groupList = [];
        if (equipmentInfoList === null || equipmentInfoList === void 0 ? void 0 : equipmentInfoList.length) {
            const equipmentItem = {
                title: '设备',
                type: 'EQUIPMENT',
                itemList: equipmentInfoList,
            };
            groupList.push(equipmentItem);
        }
        if (userInfoList === null || userInfoList === void 0 ? void 0 : userInfoList.length) {
            const groupItem = {
                title: '人员',
                type: 'USER',
                itemList: userInfoList,
            };
            groupList.push(groupItem);
        }
        if (deptInfoList === null || deptInfoList === void 0 ? void 0 : deptInfoList.length) {
            const groupItem = {
                title: '部门',
                type: 'DEPT',
                itemList: deptInfoList,
                ...selectPaneProps === null || selectPaneProps === void 0 ? void 0 : selectPaneProps.dept,
            };
            groupList.push(groupItem);
        }
        if (orgInfoList === null || orgInfoList === void 0 ? void 0 : orgInfoList.length) {
            const orgItem = {
                title: '组织',
                type: 'ORG',
                itemList: orgInfoList,
            };
            groupList.push(orgItem);
        }
        if (groupInfoList === null || groupInfoList === void 0 ? void 0 : groupInfoList.length) {
            const groupItem = {
                title: '居民群',
                type: 'GROUP',
                itemList: groupInfoList,
            };
            groupList.push(groupItem);
        }
        if (tagInfoList === null || tagInfoList === void 0 ? void 0 : tagInfoList.length) {
            const groupItem = {
                title: '标签',
                type: 'TAG',
                itemList: tagInfoList,
            };
            groupList.push(groupItem);
        }
        if (orgRelInfoList === null || orgRelInfoList === void 0 ? void 0 : orgRelInfoList.length) {
            const schoolList = orgRelInfoList === null || orgRelInfoList === void 0 ? void 0 : orgRelInfoList.filter((parameter) => (parameter === null || parameter === void 0 ? void 0 : parameter.nodeType) === 'SCHOOL');
            if ((schoolList === null || schoolList === void 0 ? void 0 : schoolList.length) > 0) {
                const orgRelSchoolItem = {
                    title: '已选学校',
                    type: 'SCHOOL',
                    unit: '组',
                    count: schoolList.length || 0,
                    itemList: schoolList,
                };
                groupList.push(orgRelSchoolItem);
            }
            const regulatoryList = orgRelInfoList === null || orgRelInfoList === void 0 ? void 0 : orgRelInfoList.filter((parameter) => (parameter === null || parameter === void 0 ? void 0 : parameter.nodeType) === 'REGULATORY');
            if ((regulatoryList === null || regulatoryList === void 0 ? void 0 : regulatoryList.length) > 0) {
                const orgRelRegulatoryItem = {
                    title: '已选教育局及下属学校',
                    type: 'REGULATORY',
                    unit: '组',
                    count: regulatoryList.length || 0,
                    itemList: regulatoryList,
                };
                groupList.push(orgRelRegulatoryItem);
            }
        }
        setGroupList(groupList);
    }, [data]);
    const funDelAll = useCallback(() => {
        // 需要展示删除时才初始化删除相关函数
        if (btnDetele) {
            const emptyData = {
                userInfoList: [],
                deptInfoList: [],
                orgInfoList: [],
                groupInfoList: [],
                tagInfoList: [],
                orgRelInfoList: [],
                equipmentInfoList: [],
            };
            setData({ ...data, ...emptyData });
            onChange({
                ...data,
                ...emptyData,
            });
        }
    }, [selectSignature, data]);
    // 获取选择结果人员及部门数
    const selectCountPriops = {
        visible: false,
        strictUser: false,
        userOrigin: selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.userOrigin,
        getTotalCount(data) {
            if (typeof (selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.getTotalCount) === 'function') {
                selectUserProps.getTotalCount(data);
            }
        },
        selectSignature,
        onOk() { },
    };
    const showSelectUser = useCallback(() => {
        SelectUser.show({
            ...selectUserProps,
            selectSignature,
            onOk(val) {
                setSelectSignature(val === null || val === void 0 ? void 0 : val.selectSignature);
                setData(val);
                onChange(val);
            },
        });
    }, [selectSignature, data]);
    // 调用时若在预览模式isNotDom传入true则不渲染dom
    if (isNotDom) {
        return null;
    }
    console.log(groupList, 'groupList');
    return (React.createElement("div", { className: "select-result" },
        (groupList === null || groupList === void 0 ? void 0 : groupList.length) ? (React.createElement("div", { className: "select-pane-wrap" },
            React.createElement(SelectUserResult, { groupList: groupList, showSelectUser: showSelectUser, funDelAll: funDelAll, btnDetele: btnDetele, btnUpdate: btnUpdate, resultTitle: resultTitle }))) : (React.createElement(Button, { onClick: showSelectUser, disabled: btnDisiabled }, btnText)),
        React.createElement(SelectUser, { ...selectCountPriops, basePath: "pc" })));
};

==> select-ss-user-result-0.0.96.tgz: package/esm/index.js <==
import React, { useCallback, useState, useEffect } from 'react';
import { Button } from 'antd';
// @ts-ignore
import SelectUser from 'select-ss-user';
import SelectUserResult from './select-user-result';
import net from './services/index';
export default ({ onChange, selectUserProps, isNotDom = false, ...others }) => {
    const [groupList, setGroupList] = useState([]);
    const [data, setData] = useState({});
    const [selectSignature, setSelectSignature] = useState(selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.selectSignature);
    const { btnText = '选择', btnDisiabled = false, resultTitle = '已选对象', btnDetele = false, btnUpdate = true, } = others;
    useEffect(() => {
        if (selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.selectSignature) {
            net
                .request(`${selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.userOrigin}/select/component/result?selectSignature=${selectSignature}`, {
                method: 'GET',
            })
                .then(({ data }) => {
                setData(data);
                setSelectSignature(selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.selectSignature);
                if ((selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.getCheckedNodes) &&
                    typeof (selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.getCheckedNodes) === 'function') {
                    selectUserProps.getCheckedNodes(data);
                }
            });
        }
    }, [selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.selectSignature]);
    useEffect(() => {
        const { userInfoList = [], deptInfoList = [], orgInfoList = [], groupInfoList = [], tagInfoList = [], equipmentInfoList = [], tvInfoList = [], orgRelInfoList = [], } = data || {};
        const { selectPaneProps } = selectUserProps;
        const groupList = [];
        if (equipmentInfoList === null || equipmentInfoList === void 0 ? void 0 : equipmentInfoList.length) {
            const equipmentItem = {
                title: '设备',
                type: 'EQUIPMENT',
                itemList: equipmentInfoList,
            };
            groupList.push(equipmentItem);
        }
        if (tvInfoList === null || tvInfoList === void 0 ? void 0 : tvInfoList.length) {
            const tvItem = {
                title: '设备',
                type: 'TV',
                itemList: tvInfoList,
            };
            groupList.push(tvItem);
        }
        if (userInfoList === null || userInfoList === void 0 ? void 0 : userInfoList.length) {
            const groupItem = {
                title: '人员',
                type: 'USER',
                itemList: userInfoList,
            };
            groupList.push(groupItem);
        }
        if (deptInfoList === null || deptInfoList === void 0 ? void 0 : deptInfoList.length) {
            const groupItem = {
                title: '部门',
                type: 'DEPT',
                itemList: deptInfoList,
                ...selectPaneProps === null || selectPaneProps === void 0 ? void 0 : selectPaneProps.dept,
            };
            groupList.push(groupItem);
        }
        if (orgInfoList === null || orgInfoList === void 0 ? void 0 : orgInfoList.length) {
            const orgItem = {
                title: '组织',
                type: 'ORG',
                itemList: orgInfoList,
            };
            groupList.push(orgItem);
        }
        if (groupInfoList === null || groupInfoList === void 0 ? void 0 : groupInfoList.length) {
            const groupItem = {
                title: '居民群',
                type: 'GROUP',
                itemList: groupInfoList,
            };
            groupList.push(groupItem);
        }
        if (tagInfoList === null || tagInfoList === void 0 ? void 0 : tagInfoList.length) {
            const groupItem = {
                title: '标签',
                type: 'TAG',
                itemList: tagInfoList,
            };
            groupList.push(groupItem);
        }
        if (orgRelInfoList === null || orgRelInfoList === void 0 ? void 0 : orgRelInfoList.length) {
            const schoolList = orgRelInfoList === null || orgRelInfoList === void 0 ? void 0 : orgRelInfoList.filter((parameter) => (parameter === null || parameter === void 0 ? void 0 : parameter.nodeType) === 'SCHOOL');
            if ((schoolList === null || schoolList === void 0 ? void 0 : schoolList.length) > 0) {
                const orgRelSchoolItem = {
                    title: '已选学校',
                    type: 'SCHOOL',
                    unit: '组',
                    count: schoolList.length || 0,
                    itemList: schoolList,
                };
                groupList.push(orgRelSchoolItem);
            }
            const regulatoryList = orgRelInfoList === null || orgRelInfoList === void 0 ? void 0 : orgRelInfoList.filter((parameter) => (parameter === null || parameter === void 0 ? void 0 : parameter.nodeType) === 'REGULATORY');
            if ((regulatoryList === null || regulatoryList === void 0 ? void 0 : regulatoryList.length) > 0) {
                const orgRelRegulatoryItem = {
                    title: '已选教育局及下属学校',
                    type: 'REGULATORY',
                    unit: '组',
                    count: regulatoryList.length || 0,
                    itemList: regulatoryList,
                };
                groupList.push(orgRelRegulatoryItem);
            }
        }
        setGroupList(groupList);
    }, [data]);
    const funDelAll = useCallback(() => {
        // 需要展示删除时才初始化删除相关函数
        if (btnDetele) {
            const emptyData = {
                userInfoList: [],
                deptInfoList: [],
                orgInfoList: [],
                groupInfoList: [],
                tagInfoList: [],
                orgRelInfoList: [],
                equipmentInfoList: [],
                tvInfoList: [],
            };
            setData({ ...data, ...emptyData });
            onChange({
                ...data,
                ...emptyData,
            });
        }
    }, [selectSignature, data]);
    // 获取选择结果人员及部门数
    const selectCountPriops = {
        visible: false,
        strictUser: false,
        userOrigin: selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.userOrigin,
        getTotalCount(data) {
            if (typeof (selectUserProps === null || selectUserProps === void 0 ? void 0 : selectUserProps.getTotalCount) === 'function') {
                selectUserProps.getTotalCount(data);
            }
        },
        selectSignature,
        onOk() { },
    };
    const showSelectUser = useCallback(() => {
        SelectUser.show({
            ...selectUserProps,
            selectSignature,
            onOk(val) {
                setSelectSignature(val === null || val === void 0 ? void 0 : val.selectSignature);
                setData(val);
                onChange(val);
            },
        });
    }, [selectSignature, data]);
    // 调用时若在预览模式isNotDom传入true则不渲染dom
    if (isNotDom) {
        return null;
    }
    console.log(groupList, 'groupList');
    return (React.createElement("div", { className: "select-result" },
        (groupList === null || groupList === void 0 ? void 0 : groupList.length) ? (React.createElement("div", { className: "select-pane-wrap" },
            React.createElement(SelectUserResult, { groupList: groupList, showSelectUser: showSelectUser, funDelAll: funDelAll, btnDetele: btnDetele, btnUpdate: btnUpdate, resultTitle: resultTitle }))) : (React.createElement(Button, { onClick: showSelectUser, disabled: btnDisiabled }, btnText)),
        React.createElement(SelectUser, { ...selectCountPriops, basePath: "pc" })));
};
